@@ -12,131 +12,158 @@ use HackaMol::Dihedral;
 use Scalar::Util qw(refaddr);
 use Carp;
 
-with 'HackaMol::NameRole','HackaMol::MolReadRole';
+with 'HackaMol::NameRole', 'HackaMol::MolReadRole';
 
 sub build_bonds {
-#take a list of n, atoms; walk down list and generate bonds 
-  my $self  = shift;
-  my @atoms = @_;
-  croak "<2 atoms passed to build_dihedrals" unless (@atoms > 1);
-  my @bonds ;
 
-  # build the bonds 
-  my $k = 0;
-  while ($k+1 <= $#atoms){
-    my $name = join("_", map{ 
-                           $_->name.$_->resid  
-                            } @atoms[$k , $k+1] 
-    );
-    push @bonds, HackaMol::Bond->new(
-                        name => $name,
-                        atoms=>[ @atoms[$k, $k+1] ] );
-    $k++;
-  }
-  return (@bonds);
+    #take a list of n, atoms; walk down list and generate bonds
+    my $self  = shift;
+    my @atoms = @_;
+    croak "<2 atoms passed to build_dihedrals" unless ( @atoms > 1 );
+    my @bonds;
+    # build the bonds
+    my $k = 0;
+    while ( $k + 1 <= $#atoms ) {
+        my $name =
+              join( "_", map { _name_resid($_,'B')} @atoms[ $k .. $k + 1 ] );
+        push @bonds,
+          HackaMol::Bond->new(
+            name  => $name,
+            atoms => [ @atoms[ $k, $k + 1 ] ]
+          );
+        $k++;
+    }
+    return (@bonds);
 }
 
 sub build_angles {
-#take a list of n, atoms; walk down list and generate angles 
-  my $self  = shift;
-  my @atoms = @_;
-  croak "<3 atoms passed to build_dihedrals" unless (@atoms > 2);
-  my @angles ;
 
-  # build the angles 
-  my $k = 0;
-  while ($k+2 <= $#atoms){
-    my $name = join("_", map{ 
-                           $_->name.$_->resid  
-                            } @atoms[$k .. $k+2] 
-    );
-    push @angles, HackaMol::Angle->new(
-                        name => $name,
-                        atoms=>[ @atoms[$k .. $k+2] ] );
-    $k++;
-  }
-  return (@angles);
+    #take a list of n, atoms; walk down list and generate angles
+    my $self  = shift;
+    my @atoms = @_;
+    croak "<3 atoms passed to build_dihedrals" unless ( @atoms > 2 );
+    my @angles;
+
+    # build the angles
+    my $k = 0;
+
+    while ( $k + 2 <= $#atoms ) {
+        my $name =
+              join( "_", map { _name_resid($_,'A')} @atoms[ $k .. $k + 2 ] );
+        push @angles,
+          HackaMol::Angle->new(
+            name  => $name,
+            atoms => [ @atoms[ $k .. $k + 2 ] ]
+          );
+        $k++;
+    }
+    return (@angles);
+}
+
+sub _name_resid {
+  my $atom    = shift;
+  my $default = shift;
+  return ($default    . $atom->resid) unless $atom->has_name;
+  return ($atom->name . $atom->resid);
 }
 
 sub build_dihedrals {
-#take a list of n, atoms; walk down list and generate dihedrals 
-  my $self  = shift;
-  my @atoms = @_;
-  croak "<4 atoms passed to build_dihedrals" unless (@atoms > 3);
-  my @dihedrals ;
 
-  # build the dihedrals 
-  my $k = 0;
-  while ($k+3 <= $#atoms){
-    my $name = join("_", map{ 
-                           $_->name.$_->resid  
-                            } @atoms[$k .. $k+3] 
-    );
-    push @dihedrals, HackaMol::Dihedral->new(
-                        name => $name, 
-                        atoms=>[ @atoms[$k .. $k+3] ] );
-    $k++;
-  }
-  return (@dihedrals);
+    #take a list of n, atoms; walk down list and generate dihedrals
+    my $self  = shift;
+    my @atoms = @_;
+    croak "<4 atoms passed to build_dihedrals" unless ( @atoms > 3 );
+    my @dihedrals;
+
+    # build the dihedrals
+    my $k = 0;
+    while ( $k + 3 <= $#atoms ) {
+        my $name =
+              join( "_", map { _name_resid($_,'D')} @atoms[ $k .. $k + 3 ] );
+        push @dihedrals,
+          HackaMol::Dihedral->new(
+            name  => $name,
+            atoms => [ @atoms[ $k .. $k + 3 ] ]
+          );
+        $k++;
+    }
+    return (@dihedrals);
 }
 
 sub group_by_atom_attr {
-# group atoms by attribute
-# Z, name, bond_count, etc. 
-  my $self  = shift;
-  my $attr  = shift;
-  my @atoms = @_; 
- 
-  my %group;
-  foreach my $atom ( @atoms ) {
-      push @{ $group{ $atom->$attr } }, $atom;
-  }
 
-  my @atomgroups =
-    map { HackaMol::AtomGroup->new( atoms => $group{$_} ) } sort
-    keys(%group);
+    # group atoms by attribute
+    # Z, name, bond_count, etc.
+    my $self  = shift;
+    my $attr  = shift;
+    my @atoms = @_;
 
-  return(@atomgroups);
+    my %group;
+    foreach my $atom (@atoms) {
+        push @{ $group{ $atom->$attr } }, $atom;
+    }
+
+    my @atomgroups =
+      map { HackaMol::AtomGroup->new( atoms => $group{$_} ) } sort
+      keys(%group);
+
+    return (@atomgroups);
 
 }
 
 sub find_bonds_brute {
-  my $self       = shift;
-  my %args       = @_;
-  my @bond_atoms = @{ $args{bond_atoms} };
-  my @atoms      = @{ $args{candidates} };
+    my $self       = shift;
+    my %args       = @_;
+    my @bond_atoms = @{ $args{bond_atoms} };
+    my @atoms      = @{ $args{candidates} };
 
-  my $fudge      = 0.45; 
+    my $fudge = 0.45;
+    my $max_bonds = 99;
 
-  $fudge = $args{fudge} if ( exists($args{fudge}) );
+    $fudge     = $args{fudge}     if ( exists( $args{fudge} ) );
+    $max_bonds = $args{max_bonds} if ( exists( $args{max_bonds} ) );
 
-  my @bonds;
-  my %name;
+    my @init_bond_counts = map {$_->bond_count} (@bond_atoms,@atoms);
 
-  foreach my $at_i (@bond_atoms){
-    my $cov_i = $at_i->covalent_radius;
-    my $xyz_i = $at_i->xyz;
+    my @bonds;
+    my %name;
 
-    foreach my $at_j (@atoms){
-        next if (refaddr($at_i) == refaddr($at_j));
-        my $cov_j = $at_j->covalent_radius;
-        my $dist  = $at_j->distance( $at_i );
+    foreach my $at_i (@bond_atoms) {
+        next if ($at_i->bond_count >= $max_bonds);
+        my $cov_i = $at_i->covalent_radius;
+        my $xyz_i = $at_i->xyz;
+
+        foreach my $at_j (@atoms) {
+            next if ( refaddr($at_i) == refaddr($at_j) );
+            next if ($at_j->bond_count >= $max_bonds);
+            my $cov_j = $at_j->covalent_radius;
+            my $dist  = $at_j->distance($at_i);
+
+            if ( $dist <= $cov_i + $cov_j + $fudge ) {
+                my $nm = $at_i->symbol . "-" . $at_j->symbol;
+                $name{$nm}++;
+                push @bonds,
+                  HackaMol::Bond->new(
+                    name  => "$nm\_" . $name{$nm},
+                    atoms => [ $at_i, $at_j ],
+                  );
+                $at_i->inc_bond_count;
+                $at_j->inc_bond_count;
+            }
 
-        if ($dist <= $cov_i + $cov_j + $fudge){
-          my $nm=$at_i->symbol."-".$at_j->symbol;
-          $name{$nm}++;
-          push @bonds,
-            HackaMol::Bond->new(
-              name  => "$nm\_".$name{$nm},
-              atoms => [ $at_i, $at_j ],
-            );
         }
-
     }
-  }
-  return (@bonds);
+  
+    my $i = 0;
+    foreach my $at (@bond_atoms,@atoms){
+      $at->reset_bond_count;
+      $at->inc_bond_count($init_bond_counts[$i]);
+      $i++;
+    }
+    return (@bonds);
+
 }
- 
+
 __PACKAGE__->meta->make_immutable;
 
 1;
@@ -151,7 +178,7 @@ HackaMol - HackaMol: Object-Oriented Library for Molecular Hacking
 
 =head1 VERSION
 
-version 0.00_04
+version 0.00_05
 
 =head1 SYNOPSIS
 
@@ -279,11 +306,17 @@ the candidates.
                                     bond_atoms => [$hg],
                                     candidates => [$mol->all_atoms],
                                     fudge      => 0.45,
+                                    max_bonds  => 6,
   );
 
-fudge is an optional argument. Default is 0.45 (open babel uses same default). 
+fudge is optional with Default is 0.45 (open babel uses same default); 
+max_bonds is optional with default of 99. max_bonds is compared against
+the atom bond count, which are incremented during the search. Before returning
+the bonds, the bond_count are returned the values before the search.  For now,
+molecules are responsible for setting the number of bonds in atoms. 
 find_bonds_brute uses a bruteforce algorithm that tests the interatomic 
-separation against the sum of the covalent radii + fudge. It does not return 
+separation against the sum of the covalent radii + fudge. It will not test
+for bond between atoms if either atom has >= max_bonds. It does not return 
 a self bond for an atom (C< next if refaddr($ati) == refaddr($atj) >).
 
 =head1 ATTRIBUTES
