@@ -1,4 +1,5 @@
 package HackaMol::Angle;
+
 #ABSTRACT: Angle class for HackaMol
 use 5.008;
 use Moose;
@@ -6,38 +7,51 @@ use namespace::autoclean;
 use Carp;
 use Math::Vector::Real;
 use MooseX::Storage;
-with Storage( 'io' => 'StorableFile' ),'HackaMol::NameRole','HackaMol::AtomGroupRole';
+with Storage( 'io' => 'StorableFile' ), 'HackaMol::NameRole',
+  'HackaMol::AtomGroupRole';
 
 has $_ => (
-            is  => 'rw'  ,
-            isa => 'Num' ,
-            default => 0 ,
-            lazy    => 1 ,
-            clearer => "clear_$_",
-            predicate => "has_$_",
-          ) foreach qw(ang_fc ang_eq);
+    is        => 'rw',
+    isa       => 'Num',
+    default   => 0,
+    lazy      => 1,
+    clearer   => "clear_$_",
+    predicate => "has_$_",
+) foreach qw(ang_fc ang_eq);
 
-sub ang_normvec{
-  my $self  = shift;
-  my @atoms = $self->all_atoms;
-  my $ang  = $self->ang_deg;
-  return V(0,0,0) if ($ang == 0 or $ang == 180);
-  my $vec1 = $atoms[1]->inter_dcoords($atoms[0]);
-  my $vec2 = $atoms[1]->inter_dcoords($atoms[2]);
-  my $v1xv2 = $vec1 x $vec2;
-  return ($v1xv2->versor);
+sub ang_normvec {
+    my $self  = shift;
+    my @atoms = $self->all_atoms;
+    my $ang   = $self->ang_deg;
+    return V( 0, 0, 0 ) if ( $ang == 0 or $ang == 180 );
+    my $vec1  = $atoms[1]->inter_dcoords( $atoms[0] );
+    my $vec2  = $atoms[1]->inter_dcoords( $atoms[2] );
+    my $v1xv2 = $vec1 x $vec2;
+    return ( $v1xv2->versor );
 }
 
-sub ang_deg{
-  my $self  = shift;
-  my @atoms = $self->all_atoms;
-  return ($atoms[1]->angle_deg($atoms[0],$atoms[2]));
+sub bisector {
+# vector that bisects the angle between to vectors of the angle
+    my $self = shift;
+    my @atoms = $self->all_atoms;
+    my $ang   = $self->ang_deg;
+    return V( 0, 0, 0 ) if ( $ang == 0 or $ang == 180 );
+    my $vec1  = $atoms[1]->inter_dcoords( $atoms[0] );
+    my $vec2  = $atoms[1]->inter_dcoords( $atoms[2] );
+    my $bvec  = ($vec1->versor+$vec2->versor)->versor;
+    return $bvec;
 }
 
-sub ang_rad{
-  my $self  = shift;
-  my @atoms = $self->all_atoms;
-  return ($atoms[1]->angle_rad($atoms[0],$atoms[2]));
+sub ang_deg {
+    my $self  = shift;
+    my @atoms = $self->all_atoms;
+    return ( $atoms[1]->angle_deg( $atoms[0], $atoms[2] ) );
+}
+
+sub ang_rad {
+    my $self  = shift;
+    my @atoms = $self->all_atoms;
+    return ( $atoms[1]->angle_rad( $atoms[0], $atoms[2] ) );
 }
 
 has 'angle_energy_func' => (
@@ -47,21 +61,21 @@ has 'angle_energy_func' => (
     lazy    => 1,
 );
 
-
 sub _build_angle_energy_func {
+
     #my $self = shift; #self is passed by moose, but we don't use it here
     my $subref = sub {
         my $angle = shift;
-        my $val = ( $angle->ang_deg - $angle->ang_eq )**2;
-        return ($angle->ang_fc*$val);
+        my $val   = ( $angle->ang_deg - $angle->ang_eq )**2;
+        return ( $angle->ang_fc * $val );
     };
     return ($subref);
 }
 
 sub angle_energy {
-    my $self  = shift;
-    return (0) unless ($self->ang_fc > 0);
-    my $energy = &{$self->angle_energy_func}($self,@_);
+    my $self = shift;
+    return (0) unless ( $self->ang_fc > 0 );
+    my $energy = &{ $self->angle_energy_func }( $self, @_ );
     return ($energy);
 }
 
@@ -79,7 +93,7 @@ HackaMol::Angle - Angle class for HackaMol
 
 =head1 VERSION
 
-version 0.00_04
+version 0.00_05
 
 =head1 SYNOPSIS
 
@@ -142,9 +156,14 @@ user may define.  See descriptions below.
 
 =head2 ang_normvec
 
-no arguments. returns Math::Vector::Real object from the normalized cross 
+no arguments. returns Math::Vector::Real (MVR) object from the normalized cross 
 product of the atom21 and atom23 interatomic vectors.
 
+=head2 bisector
+
+no arguments. returns vector (MVR) that bisects the angle between the two
+vectors of the angle.   
+
 =head2 ang_deg 
 
 no arguments. returns the angle (degrees) between the atom21 and atom23 vectors. 
