@@ -1,24 +1,27 @@
 package HackaMol::AtomGroup;
-#ABSTRACT: HackaMol AtomGroup class 
+
+#ABSTRACT: HackaMol AtomGroup class
 use 5.008;
 use Moose;
 use namespace::autoclean;
 use Carp;
 use MooseX::Storage;
-with Storage( 'io' => 'StorableFile' ), 'HackaMol::NameRole', 'HackaMol::AtomGroupRole';
+with Storage( 'io' => 'StorableFile' ), 'HackaMol::NameRole',
+  'HackaMol::AtomGroupRole';
 
 sub Rg {
- #radius of gyration. 
-    my $self         = shift;
-    return(0) unless ($self->count_atoms);
-    my @atoms        = $self->all_atoms;
-    my $com          = $self->COM;
-    my $total_mass   = $self->total_mass;
-    my @masses = map { $_->mass} @atoms;
-    my @dvec2  = map{$_*$_} map { $_->get_coords($_->t) - $com } @atoms;
-    my $sum    = 0;
-    $sum      += $masses[$_]*$dvec2[$_] foreach 0 .. $#dvec2;
-    return( sqrt($sum/$total_mass) );
+
+    #radius of gyration.
+    my $self = shift;
+    return (0) unless ( $self->count_atoms );
+    my @atoms      = $self->all_atoms;
+    my $com        = $self->COM;
+    my $total_mass = $self->total_mass;
+    my @masses     = map { $_->mass } @atoms;
+    my @dvec2 = map { $_ * $_ } map { $_->get_coords( $_->t ) - $com } @atoms;
+    my $sum   = 0;
+    $sum += $masses[$_] * $dvec2[$_] foreach 0 .. $#dvec2;
+    return ( sqrt( $sum / $total_mass ) );
 }
 
 __PACKAGE__->meta->make_immutable;
@@ -31,11 +34,11 @@ __END__
 
 =head1 NAME
 
-HackaMol::AtomGroup - HackaMol AtomGroup class 
+HackaMol::AtomGroup - HackaMol AtomGroup class
 
 =head1 VERSION
 
-version 0.00_04
+version 0.00_05
 
 =head1 SYNOPSIS
 
