@@ -182,32 +182,70 @@ sub rotate {
 }
 
 sub print_xyz {
-    my $self  = shift;
-    my $file  = shift; # could be file or filehandle 
-    
-    my $fh = \*STDOUT ; # default to standard out
-    # if argument is passed, check if filehandle 
-    if (defined($file)){
-      if (ref($file) and reftype($file) eq "GLOB" ){
-        $fh = $file;
-      }
-      else {
-        carp "overwrite $file" if (-e $file);
-        $fh = FileHandle->new(">$file");
-      }
-    }
+    my $self = shift;
+    my $fh = _open_file_unless_fh(shift);
 
     my @atoms = $self->all_atoms;
     print $fh $self->count_atoms . "\n\n";
     foreach my $at (@atoms) {
-        printf $fh ( "%3s %10.6f %10.6f %10.6f\n",
-            $at->symbol, @{ $at->get_coords( $at->t ) } );
+        printf $fh (
+            "%3s %10.6f %10.6f %10.6f\n",
+            $at->symbol, @{ $at->get_coords( $at->t ) }
+        );
     }
 
-    return ($fh); # returns filehandle for future writing
+    return ($fh);    # returns filehandle for future writing
 
 }
 
+sub print_pdb {
+    my $self = shift;
+    my $fh = _open_file_unless_fh(shift);
+
+    my @atoms = $self->all_atoms;
+    foreach my $at (@atoms) {
+        printf $fh (
+            "%-6s%5i  %-3s%1s%3s%2s%4i%1s%11.3f%8.3f%8.3f%6.2f%6.2f%12s\n",
+            ( map{$at->$_} qw ( 
+                              record_name 
+                              serial 
+                              name 
+                              altloc  
+                              resname
+                              chain
+                              resid
+                              icode
+                            )
+            ), @{ $at->get_coords( $at->t ) },
+            $at->occ, $at->bfact, $at->symbol, $at->charge
+        );
+
+    }
+    
+    return ($fh);    # returns filehandle for future writing
+
+}
+
+sub _open_file_unless_fh {
+
+    my $file = shift;    # could be file or filehandle
+
+    my $fh = \*STDOUT;   # default to standard out
+                         # if argument is passed, check if filehandle
+    if ( defined($file) ) {
+        if ( ref($file) and reftype($file) eq "GLOB" ) {
+            $fh = $file;
+        }
+        else {
+            carp "overwrite $file" if ( -e $file );
+            $fh = FileHandle->new(">$file");
+        }
+    }
+
+    return ($fh);
+}
+
+
 no Moose::Role;
 
 1;
@@ -222,7 +260,7 @@ HackaMol::AtomGroupRole - Role for a group of atoms
 
 =head1 VERSION
 
-version 0.00_04
+version 0.00_05
 
 =head1 SYNOPSIS
 
@@ -364,6 +402,16 @@ origin as arguments. Optional argument: integer tf.
 Rotates all atoms in the group around the MVR vector. Pass tf to the translate 
 method to store new coordinates in tf rather than atom->t.
 
+=head2 print_xyz
+
+optional argument: filename or filehandle.  with no argument, prints xyz formatted output to STDOUT. pass 
+a filename and an xyz file with that name will be written or overwritten (with warning). pass filehandle 
+for continuous writing to an open filehandle.
+
+=head2 print_pdb
+
+same as print_xyz, but for pdb formatted output
+
 =head1 ARRAY METHODS
 
 =head2 push_atoms, get_atoms, set_atoms, all_atoms, count_atoms, clear_atoms
