@@ -1,4 +1,5 @@
 package HackaMol::Dihedral;
+
 #ABSTRACT: Dihedral Angle class for HackaMol
 use 5.008;
 use Moose;
@@ -6,26 +7,27 @@ use namespace::autoclean;
 use Carp;
 use MooseX::Storage;
 use Math::Trig;
-with Storage( 'io' => 'StorableFile' ),'HackaMol::NameRole','HackaMol::AtomGroupRole';
+with Storage( 'io' => 'StorableFile' ), 'HackaMol::NameRole',
+  'HackaMol::AtomGroupRole';
 
 has $_ => (
-            is  => 'rw'  ,
-            isa => 'Num' ,
-            default => 0 ,
-            lazy    => 1 ,
-            clearer => "clear_$_",
-          ) foreach qw(dihe_fc dihe_dphase dihe_eq dihe_mult);
+    is      => 'rw',
+    isa     => 'Num',
+    default => 0,
+    lazy    => 1,
+    clearer => "clear_$_",
+) foreach qw(dihe_fc dihe_dphase dihe_eq dihe_mult);
 
-sub dihe_deg{
-  my $self  = shift;
-  my @atoms = $self->all_atoms;
-  return ($atoms[0]->dihedral_deg($atoms[1],$atoms[2],$atoms[3]));
+sub dihe_deg {
+    my $self  = shift;
+    my @atoms = $self->all_atoms;
+    return ( $atoms[0]->dihedral_deg( $atoms[1], $atoms[2], $atoms[3] ) );
 }
 
-sub dihe_rad{
-  my $self  = shift;
-  my @atoms = $self->all_atoms;
-  return ($atoms[0]->dihedral_rad($atoms[1],$atoms[2],$atoms[3]));
+sub dihe_rad {
+    my $self  = shift;
+    my @atoms = $self->all_atoms;
+    return ( $atoms[0]->dihedral_rad( $atoms[1], $atoms[2], $atoms[3] ) );
 }
 
 has 'improper_dihe_energy_func' => (
@@ -35,12 +37,11 @@ has 'improper_dihe_energy_func' => (
     lazy    => 1,
 );
 
-
 sub _build_improper_dihe_energy_func {
     my $subref = sub {
         my $dihedral = shift;
-        my $val = ( $dihedral->dihe_deg - $dihedral->dihe_eq )**2;
-        return ($dihedral->dihe_fc*$val);
+        my $val      = ( $dihedral->dihe_deg - $dihedral->dihe_eq )**2;
+        return ( $dihedral->dihe_fc * $val );
     };
     return ($subref);
 }
@@ -52,28 +53,29 @@ has 'torsion_energy_func' => (
     lazy    => 1,
 );
 
-
 sub _build_torsion_energy_func {
     my $subref = sub {
         my $dihedral = shift;
-        my $val = 1 + cos($dihedral->dihe_mult*$dihedral->dihe_rad 
-                          - $dihedral->dihe_dphase);
-        return ($dihedral->dihe_fc*$val);
+        my $val =
+          1 +
+          cos( $dihedral->dihe_mult * $dihedral->dihe_rad -
+              $dihedral->dihe_dphase );
+        return ( $dihedral->dihe_fc * $val );
     };
     return ($subref);
 }
 
 sub torsion_energy {
-    my $self  = shift;
-    return (0) unless ($self->dihe_fc > 0 );
-    my $energy = &{$self->torsion_energy_func}($self,@_);
+    my $self = shift;
+    return (0) unless ( $self->dihe_fc > 0 );
+    my $energy = &{ $self->torsion_energy_func }( $self, @_ );
     return ($energy);
 }
 
 sub improper_dihe_energy {
-    my $self  = shift;
-    return (0) unless ($self->dihe_fc > 0 );
-    my $energy = &{$self->improper_dihe_energy_func}($self,@_);
+    my $self = shift;
+    return (0) unless ( $self->dihe_fc > 0 );
+    my $energy = &{ $self->improper_dihe_energy_func }( $self, @_ );
     return ($energy);
 }
 
@@ -91,7 +93,7 @@ HackaMol::Dihedral - Dihedral Angle class for HackaMol
 
 =head1 VERSION
 
-version 0.00_04
+version 0.00_05
 
 =head1 SYNOPSIS
 
