@@ -1,27 +1,27 @@
-package references;
-# ABSTRACT: some useful references 
+package References;
+
+# ABSTRACT: some useful references
 use Moose;
 use namespace::autoclean;
 
 has '_refs' => (
-                  traits   => [ 'Array' ],
-                  isa      => 'ArrayRef',
-                  default  => sub { [] },
-                  handles  =>
-                  {
-                    "add_refs"   => 'push'    ,
-                    "get_refs"   => 'get'     ,
-                    "all_refs"   => 'elements',
-                    "count_refs" => 'count'   ,
-                  },
-                  lazy   => 1,
-               );
+    traits  => ['Array'],
+    isa     => 'ArrayRef',
+    default => sub { [] },
+    handles => {
+        "add_refs"   => 'push',
+        "get_refs"   => 'get',
+        "all_refs"   => 'elements',
+        "count_refs" => 'count',
+    },
+    lazy => 1,
+);
 
-sub build_references{
-  my $self = shift;
-  $self->add_refs($_) foreach qw(http://perlmol.org);
-  $self->add_refs(
-                  '@article{o2011open,
+sub build_references {
+    my $self = shift;
+    $self->add_refs($_) foreach qw(http://perlmol.org);
+    $self->add_refs(
+        '@article{o2011open,
                     title={Open Babel: An open chemical toolbox},
                     author={O’Boyle, Noel M and Banck, Michael and James, Craig A and Morley, Chris and Vandermeersch, Tim and Hutchison, Geoffrey R},
                     journal={Journal of cheminformatics},
@@ -31,9 +31,9 @@ sub build_references{
                     year={2011},
                     publisher={Springer}
                    }'
-                 );
-   $self->add_refs(
-                  '@article{hanwell2012avogadro,
+    );
+    $self->add_refs(
+        '@article{hanwell2012avogadro,
                     title={Avogadro: an advanced semantic chemical editor, visualization, and analysis platform},
                     author={Hanwell, Marcus D and Curtis, Donald E and Lonie, David C and Vandermeersch, Tim and Zurek, Eva and Hutchison, Geoffrey R},
                     journal={Journal of cheminformatics},
@@ -43,8 +43,8 @@ sub build_references{
                     year={2012},
                     publisher={Springer}
                    }'
-                 );
-} 
+    );
+}
 
 __PACKAGE__->meta->make_immutable;
 
@@ -54,11 +54,11 @@ __PACKAGE__->meta->make_immutable;
 
 =head1 NAME
 
-references - some useful references 
+References - some useful references
 
 =head1 VERSION
 
-version 0.00_04
+version 0.00_05
 
 =head1 AUTHOR
 
